@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2016-06-28'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2016-12-12'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -299,8 +299,16 @@ sub __gen_table {
             } # for $colidx
         } # END align columns
 
-        require Text::Table::Tiny;
-        Text::Table::Tiny::table(rows=>$data, header_row=>$header_row) . "\n";
+        my $fres;
+        if (my $backend = $ENV{FORMAT_PRETTY_TABLE_BACKEND}) {
+            require Text::Table::Any;
+            $fres = Text::Table::Any::table(rows=>$data, header_row=>$header_row, backend=>$backend);
+        } else {
+            require Text::Table::Tiny;
+            $fres = Text::Table::Tiny::table(rows=>$data, header_row=>$header_row);
+        }
+        $fres .= "\n" unless $fres =~ /\R\z/ || !length($fres);
+        $fres;
     } elsif ($format eq 'csv') {
         no warnings 'uninitialized';
         join(
@@ -456,7 +464,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.20 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-06-28.
+This document describes version 0.21 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-12-12.
 
 =head1 SYNOPSIS
 
@@ -470,6 +478,16 @@ This document describes version 0.20 of Perinci::Result::Format::Lite (from Perl
 
 =head1 ENVIRONMENT
 
+=head2 FORMAT_PRETTY_TABLE_BACKEND => str
+
+If this is set, will render text table using L<Text::Table::Any> (with
+C<backend> set to the value of this environment variable) instead of the default
+L<Text::Table::Tiny>. This is useful if you want to output text table in a
+different format, for example to generate Org tables (make sure
+L<Text::Table::Org> backend is already installed):
+
+ % FORMAT_PRETTY_TABLE_BACKEND=Text::Table::Org lcpan rdeps Getopt::Lucid
+
 =head2 FORMAT_PRETTY_TABLE_COLUMN_ORDERS => array (json)
 
 Set the default of C<table_column_orders> in C<format_options> in result
